@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #  Copyright (c) 2020, Apple Inc. All rights reserved.
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
@@ -11,9 +9,7 @@ import logging
 import tensorflow as tf
 
 from ..basic_graph_ops import const_determined_nodes
-from .delete_constant import delete_unnecessary_constant_nodes
 from coremltools._deps import _get_version
-from coremltools.converters._profile_utils import _profile
 from coremltools.converters.mil.mil import types
 from coremltools.converters.mil.mil.types.type_mapping import numpy_val_to_builtin_val
 
@@ -65,7 +61,6 @@ def _get_const_nodes(fn):
     return new_graph, list(constant_nodes), constant_node_num_outputs
 
 
-@_profile
 def _constant_propagation(fn, new_graph, constant_nodes, constant_node_num_outputs):
     try:
         if len(constant_nodes) > 0:
@@ -156,7 +151,6 @@ def _constant_propagation(fn, new_graph, constant_nodes, constant_node_num_outpu
         logging.exception("Constant Propagation pass failed: {}".format(e))
 
 
-@_profile
 def constant_propagation(tfssa):
     # we are going to rely on the TensorFlow graph to perform constant
     # propagation. For each graph, we construct a new graph comprising
@@ -165,4 +159,3 @@ def constant_propagation(tfssa):
     for f in tfssa.functions.values():
         const_nodes_info = _get_const_nodes(f)
         _constant_propagation(f, *const_nodes_info)
-    delete_unnecessary_constant_nodes(tfssa)
