@@ -40,7 +40,7 @@ from coremltools.converters.mil.mil.operation import (
 )
 
 from ._op_reqs import register_op
-from ._utils import promoted_primitive_type
+from ._utils import promoted_primitive_type, MAX_SIZE_CONSTANT_FOLDING
 
 
 @register_op(doc_str="")
@@ -423,17 +423,19 @@ class pad(Operation):
 
     Parameters
     ----------
+    
     x: tensor<[\*D_in],T>  (Required)
 
     pad: tensor<[2\*N],i32> (Required)
-        * ``N <= D_in``: Last ``N`` dimensions of ``x`` are padded as follows: For
-          each dimension ``i`` of ``x`` if ``i >= D_in - N``:
+        ``N <= D_in``. Last ``N`` dimensions of ``x`` are padded as follows:
+        
+        * For each dimension ``i`` of ``x`` if ``i >= D_in - N``:
             * pad ``pad[2*i]`` elements before ``x[..,i,..]``
             * pad ``pad[2*i+1]`` elements after ``x[..,i,..]``
         * If mode is "reflect" then ``pad[2*i]`` and ``pad[2*i+1]`` can be at
-        most ``D[i]-1``.
+          most ``D[i]-1``.
         * If mode is "replicate" then ``pad[2*i]`` and ``pad[2*i+1]`` can be
-        at most ``D[i]``.
+          at most ``D[i]``.
 
     mode: const<str> (Optional)
         * Default to ``constant``.
@@ -559,7 +561,12 @@ class range_1d(Operation):
         start = self.start.val
         end = self.end.val
         step = self.step.val
-        return np.arange(start, end, step).astype(np.int32)
+        shape = (end - start) / step
+        # To prevent from creating constant greater then 1MB,
+        # a upper bound of the size of the resulting array is set.
+        if shape > MAX_SIZE_CONSTANT_FOLDING:
+            return None
+        return np.arange(start, end, step)
 
     def type_inference(self):
         start = self.start.sym_val
