@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
-
 #  Copyright (c) 2020, Apple Inc. All rights reserved.
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
+import logging
 
-import numpy as np
 from coremltools.converters.mil.mil.types.symbolic import (
     is_symbolic,
     any_variadic,
@@ -15,7 +13,7 @@ from coremltools.converters.mil.mil.types.symbolic import (
 from coremltools.converters.mil.mil import Builder as mb
 from coremltools.converters.mil.mil.passes.pass_registry import register_pass
 from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
-import logging
+
 
 def _remove_symbolic_reshape_block(block):
     num_changes = 0
