@@ -1,11 +1,19 @@
+# Copyright (c) 2021, Apple Inc. All rights reserved.
+#
+# Use of this source code is governed by a BSD-3-clause license that can be
+# found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
+
 import unittest
 
-from coremltools._deps import _HAS_KERAS2_TF
-from coremltools.proto import Model_pb2
-from coremltools.proto import FeatureTypes_pb2
-from coremltools.proto import NeuralNetwork_pb2
 import pytest
 
+from coremltools._deps import _HAS_KERAS2_TF
+from coremltools.proto import (
+    FeatureTypes_pb2,
+    Model_pb2,
+    NeuralNetwork_pb2
+)
+
 if _HAS_KERAS2_TF:
     import tensorflow as tf
     from keras.models import Sequential, Model
